@@ -518,6 +518,9 @@ INVALIDPARAMETERVALUE_PREHEATUNAVAILABLEZONES = 'InvalidParameterValue.PreheatUn
 #  无效参数值。参数值取值范围不合法。
 INVALIDPARAMETERVALUE_RANGE = 'InvalidParameterValue.Range'
 
+# 请求需要区域镜像。
+INVALIDPARAMETERVALUE_REQUIREDLOCATIONIMAGE = 'InvalidParameterValue.RequiredLocationImage'
+
 # 快照ID不合要求，请提供规范的快照ID，类似snap-xxxxxxxx，字母x代表小写字符或者数字
 INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMalformed'
 
@@ -950,6 +953,9 @@ UNSUPPORTEDOPERATION_LOCALDATADISKCHANGEINSTANCEFAMILY = 'UnsupportedOperation.L
 # 不支持正在本地盘转云盘的磁盘，请稍后发起请求。
 UNSUPPORTEDOPERATION_LOCALDISKMIGRATINGTOCLOUDDISK = 'UnsupportedOperation.LocalDiskMigratingToCloudDisk'
 
+# 此请求不支持该区域镜像,请更换其他镜像。
+UNSUPPORTEDOPERATION_LOCATIONIMAGENOTSUPPORTED = 'UnsupportedOperation.LocationImageNotSupported'
+
 # 从市场镜像创建的自定义镜像不支持导出。
 UNSUPPORTEDOPERATION_MARKETIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.MarketImageExportUnsupported'
 
@@ -977,6 +983,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTIMPORTINSTANCESACTIONTIMER = 'UnsupportedOperatio
 # 操作不支持当前实例
 UNSUPPORTEDOPERATION_NOTSUPPORTINSTANCEIMAGE = 'UnsupportedOperation.NotSupportInstanceImage'
 
+# 实例存在未支付订单。
+UNSUPPORTEDOPERATION_NOTSUPPORTUNPAIDORDER = 'UnsupportedOperation.NotSupportUnpaidOrder'
+
 # 该操作仅支持预付费账户
 UNSUPPORTEDOPERATION_ONLYFORPREPAIDACCOUNT = 'UnsupportedOperation.OnlyForPrepaidAccount'
 
